@@ -5,7 +5,10 @@ TTT Package :-
 """
 
 from .__errors__ import ChoiceError as __ChErr
-from .__functions__ import commitToGrid as __CTG, comptrMove as __CM, gridRepr as __GR, isGameOver as __IGO, log as __log, showProb as showProbability, updateProb as __UP
+from .__functions__ import commitToGrid as __CTG, comptrMove as __CM
+from .__functions__ import gridRepr as __GR, isGameOver as __IGO
+from .__functions__ import log as __log, showProb as showProbability
+from .__functions__ import updateProb as __UP
 from tempfile import TemporaryFile as __TF
 
 def play():
@@ -34,10 +37,7 @@ def play():
 		tmpfile.write(f"Your Choice : {playerChoice}\n")
 
 	# Setting Computer's Choice based on Player's Choice
-	if playerChoice == 'X':
-		comptrChoice = 'O'
-	else:
-		comptrChoice = 'X'
+	comptrChoice = 'O' if playerChoice == 'X' else "X"
 
 	# Temporarily Logging the choice
 	tmpfile.write(f"My Choice : {comptrChoice}\n\n")
